pub struct ToastifyOptions {
pub text: String,
pub duration: u32,
pub destination: Option<String>,
pub close: bool,
pub gravity: Gravity,
pub position: Position,
pub new_window: bool,
pub stop_on_focus: bool,
pub class_name: Option<String>,
pub style: Object,
pub on_click: JsValue,
}Fields
text: Stringduration: u32destination: Option<String>close: boolgravity: Gravityposition: Positionnew_window: boolstop_on_focus: boolclass_name: Option<String>style: Objecton_click: JsValueImplementations
Sourceimpl ToastifyOptions
impl ToastifyOptions
Sourcepub fn add_style(
self,
style_property: &str,
value: &str,
) -> Result<Self, JsValue>
pub fn add_style( self, style_property: &str, value: &str, ) -> Result<Self, JsValue>
Add a style property to the toast Style properties match HTML DOM styles
Errors
Returns an error if the style property is not a valid HTML DOM style
pub fn add_on_click<T>(self, callback: T) -> Selfwhere
T: Fn(),
pub fn show(self)